% rwrtHOM2s1s2
% Based on the litterature:
% Ghim C.-M. and Almaas E. Two-component genetic switch as a synthetic
% module with tunable stability. Pys. Rev. Letters, 103:028101, 2009.
% By Sigurd Hagen Johansen
% Made 27.02.2011
function y = rwrtHOM2beta1beta2(x,in,in2)
% Use MatLab to model the system HOM2

% Description of parameters:
% s = K3/K5;        promoter leakage
% u = K3/[RNAp];    RNAp-promoter dissociation constant scaled by the
%                   concentration of free RNAp
% beta = (alpha_m * alpha_p) / (K2_i * gamma_m * gamma_p);
%                   Gene expression efficiency
% r = K2_i / K4_i;      coopreative binding affinity (if r > 1)

% Setting values of parameters for protein 1 (dp1/dt):
s1 = 0.01;
beta1 = in;% 17.5;
u1 = 3;
r1 = 25;
K1_1 = 10; % [nM]
K2_1 = 20;  % from Ghim & Almaas (2009)
sigma1 = 10 ; %ratio of dimer to monomer lifetime from Ghim & Almaas (2009)

% Setting values of parameters for protein 2 (dp2/dt):
s2 = s1;            % Promoter leakage K3/K5
beta2 = in2;%beta1;      % Gene expression efficiency
u2 = u1;            % K3/[RNAp]
r2 = r1;            % 
K1_2 = K1_1;%10; % [nM]
K2_2 = K2_1; % from Ghim & Almaas (2009)
sigma2 = sigma1; %ratio of dimer to monomer lifetime from Ghim & Almaas (2009)

% Dimensionless parameters for dp1/dt:
lambda1 = beta1 / ( 1 + (u1/s1));
mu1 = (s1 + u1) / (1 + u1) ;
nu1 = (u1 *(1 - s1)) / (s1 * (1 + u1));
theta1 = K2_1/K1_1;
kappa1 = sigma1/theta1 ;

% Dimensionless parameters for dp2/dt:
lambda2 = beta2 / ( 1 + (u2/s2));
mu2 = (s2 + u2) / (1 + u2) ;
nu2 = (u2 *(1 - s2)) / (s2 * (1 + u2));
theta2 = K2_2/K1_2;
kappa2 = sigma2/theta2;

% let x(1) denote protein 1 and x(2) denote protein 2
% The dx/dt is a funciton of both the x(1) and x(2)
% dx/dt = F(x,y) - G(x,y), where F is the synthesis rate and G is the degradation rate 

% Setting the sythesis rate, F1, and decay rate, G1, for x(1)
F1 = (2*sqrt(theta1*x(1)))*(lambda1 * (1 + nu1 + mu1*x(2) + mu1*r1*(x(2)^2)));
G1 = (2*x(1)+(4*x(1)^(2/3))/(kappa1*sqrt(theta1)))*(1+mu1*x(2)+mu1*r1*(x(2)^2));
% Setting the sythesis rate, F2, and decay rate, G2, for x(2)
F2 = (2*sqrt(theta2*x(2)))*(lambda2 * (1 + nu2 + mu2*x(1) + mu2*r2*(x(1)^2)));
G2 = (2*x(2)+(4*x(2)^(2/3))/(kappa2*sqrt(theta2)))*(1+mu2*x(1)+mu2*r2*(x(1)^2));

y = [F1 - G1;
    F2 - G2];