function A = stestasea(F,min,max,steps,fvallim,funtol,varargin)
% By Sigurd Hagen Johansen
% Modified 31.01.2011, old file saved as stestasea2.m
% stestasea:    Steady State Search, Finds steady states for a system, for
%               values of x(1) and x(2) for the function F using the
%               built in function fsolve
% F:            The function to be evaluated by fsolve, must be a function
%               on the form y = [f(x(1),x(2)); f(x(1),x(2))] and input as
%               @functionname
% min:          The power of the minimum initial guessing value used as
%               input for fsolve.
% max:          The power of the maximum initial guessing value used as
%               input for fsolve.
% steps:        Number of steps to the next power of 10
% fvallim:      Adjust how close to zero the values of a function needs to be
%               in order to be accepted as a value
% funtol:       Adjust the TolFun and XTol values for fsolve
% varargin:     Length(varargin)< 2 Takes in parametersvalues to be evaluated
%               by fsolve. The number of parameter values needs to be in
%               accordnace with the number of parameters that may be changed in
%               the function specified by F.

%--------------------------------------------------------------------------
% Generate a matrix to contain the steady states found
%--------------------------------------------------------------------------

arows=0; % How many coloumns the new matrix A will get                     
A = zeros(arows,2); % Create matrix A, that later will contain the answers x*(1),x*(2),fval(1),fval(2)

%--------------------------------------------------------------------------
% Start the search for steady states for the system with the given inputs
%--------------------------------------------------------------------------

for i= min:(1/steps):max
    x = 10^(i);
    for j = min:(1/steps):max
        y = 10^(j);
        x0 = [x; y];           % Initial guess at the solution
        options=optimset('Display','off','TolFun',funtol,'TolX',funtol);   % Option to display output
        if isempty(varargin)
            [x1,fval] = fsolve(F,x0,options);  % Call solver
        elseif length(varargin(1,:))==1
            [x1,fval] = fsolve(F,x0,options,varargin{1});
        elseif length(varargin(1,:))==2
            [x1,fval] = fsolve(F,x0,options,varargin{1},varargin{2});
        end
        if abs(fval(:,1))< fvallim
            xx=1;
            k=1;
            while k<=length(A(:,1))
                avvik=abs(real(A(k,1:2))-real(x1(:,1)'));
                if(avvik(1) < 0.001 && avvik(2) < 0.001)
                    xx=0;
                    break
                end
                k = k +1;
            end
            if(xx)
                arows = arows + 1;
                A(arows,:) = x1(:,1)';
            end
        end
    end
end

end
