% simplhom2scan
% Created 10.02.2011
% By Sigurd Hagen Johansen
%___________________________Descripiton____________________________________
% To find steady states of a function, F, with the two parameter input values
% in and in2, based on the steday state values of a previous set of
% parameter values not too far from in and in2. These previous values are
% contained in the matrix A(m,n). Limits to the steady state values x are
% set by ilim, that restricts the size of the imaginary part to a
% solution, tol, serving to adjust the TolX and TolFun values for fsolve,
% lim, that filters soulutions too far from zero, and the steady state
% concentrations also need to be positive. The result is a matrix C(n x 2),
% where n is the number of steady states found and C(n,1)=x(1),
% C(n,2)=x(2).
function C = simplhom2scan(F,A,in,in2,width,step,tol,lim,ilim)
crows = 0;
C = zeros(crows,2);
for i=1:length(A(:,1))
    options=optimset('Display','off','TolFun',tol,'TolX',tol);        
    for j=-width:(width/step):width
        for m=-width:(width/step):width
            x0 = [A(i,1)*10^(j);A(i,2)*10^(m)];
            [x1,fval] = fsolve(F,x0,options,in,in2);
            % Criterias for the steady states to be accepted
            positive = x1 > 0;
            closezero = abs(fval) < lim;
            noncomplex = ilim > abs(imag(x1));
            if [positive;closezero;noncomplex] % Check if the solutions from fsolve can be accepted
                xx=1;
                k=1;
                while k<(length(C(:,1))+1)
                    avvik=abs(real(C(k,1:2))-real(x1(:,1)')); % Check if the solution is already found or a new one
                    if(avvik(1) < 0.001 && avvik(2) < 0.001)
                        xx=0;
                        break
                    end
                    k = k +1;
                end
                if(xx)
                    crows = crows + 1; % if the new solution is unique for the set of in and in2 values, save it in the matrix C
                    C(crows,:) = x1(:,1)';
                end
            end
        end
    end
end
