function B = stabilityss(F,A,varargin)
%By Sigurd Hagen Johansen
% Modified 31.01.2011
% stabilityss1: Determine the stability of steady states, possibly found by
%               the use of findss
% F:        must be a function on the form y = [f(x(1),x(2)); f(x(1),x(2))] 
%           input as @functionname
% A:        A n x 2 matrix that preferably consists of the steady states
%           found by the use of findss on the function F.
% varargin: length(varargin)< 2 Takes in parametersvalues to be evaluated
%           by fsolve. The number of parameter values needs to be in
%           accordnace with the number of parameters that may be changed in
%           the function specified by F.

B = zeros(length(A(:,1)),3);

% Steady states %
%______________________________________________
% Stable Star and degen.node     ss == 5
% Centers:                      ss == 4
% Stable node:                  ss == 3
% Stable spiral:                ss == 2
% Saddle point (unstable):      ss == -1
% Unstable spiral:              ss == -2
% Unstable node:                ss == -3
% Non-isolated fixed point:     ss == -4
% Unstable Star and degen.node   ss == -5

almostzero = 1e-12;

for i= 1:length(A(:,1))
    v = A(i,:)';
    options = optimset('Display','off');
    if nargin < 3
        [~, ~, ~, ~, jacobian] = fsolve(F,v,options);
    elseif nargin < 4
        [~, ~, ~, ~, jacobian] = fsolve(F,v,options,varargin{1});
    elseif nargin < 5
        [~, ~, ~, ~, jacobian] = fsolve(F,v,options,varargin{1},varargin{2});
    end
    tau = trace(jacobian);
    delta = det(jacobian);
    limit = delta^2 - 4*tau;
    if delta > almostzero && tau == 0
        ss = 4;
        result = [A(i,:),ss];
    elseif delta > almostzero && limit > almostzero && tau < almostzero
        ss = 3;
        result = [A(i,:),ss];
    elseif delta > almostzero && limit < almostzero && tau < almostzero
        ss = 2;
        result = [A(i,:),ss];
    elseif delta > almostzero && tau < almostzero && limit == 0 
        ss = -5;
        result = [A(i,:),ss];
    elseif delta > almostzero && tau > almostzero && limit == 0 
        ss = 5;
        result = [A(i,:),ss];        
    elseif delta < almostzero 
        ss = -1;
        result = [A(i,:),ss];
    elseif delta > almostzero && limit < almostzero && tau > almostzero
        ss = -2;
        result = [A(i,:),ss];
    elseif delta > almostzero && limit > almostzero && tau > almostzero
        ss = -3;
        result = [A(i,:),ss];
    else %delta == 0
        ss = -4;
        result = [A(i,:),ss];
    end
    B(i,:) = result(1,:);
end