% s2vsbeta2
% Created 20.02.2011
% By Sigurd Hagen Johansen
% Last modified 26.02.2011

% Find steady states of the function described in rwrthom2.m with s2 = in
% and beta2 = in2.

tic

F=@rwrthom2s2beta2;
minimum =-4;
maximum = 4;
nsteps = 2;
lim = 1e-7;
ilim = 1e-9;
tol = 1e-7;

% Set the interval for the parameter to be scanned for (s_2)
instart = -3; % 10^instart
instop = 0; % 10^instop
% Set the interval for the parameter to be scanned for (beta_2)
in2start = 0; % 10^in2start
in2stop = 3; % 10^in2stop
insteps= 30; % 10^(1/insteps) -> steps per 10^x

% Inital value guess width around previous values
w = 1; % preval*10^(+-width)
s = 2; % # steps on each side of the previous value

% To increase the probability of finding a steady state:
wmod = 2; % if the first search fails the outer inital values will be 10^(wmod)
smod = 9; % if the first search fails # steps on each side of the previous value is increased to smod

% Create a starting ponit within the bistable region
ininitial =10^(-0.59);
in2initial = 4;
E = stestasea(F,minimum,maximum,nsteps,lim,tol,ininitial,in2initial);
D = E;
%--------------------------------------------------------------------------
% Make a bifurcation plot moving along the plane with a negative slope 
% appearing linear in the log-log-space - save scan as C
%--------------------------------------------------------------------------

bifurrows = 0;
bifur = zeros(bifurrows,2);

resrows = 0;
result = zeros(resrows, 5);

diff = abs(log10(ininitial))-abs(log10(in2initial));
a = (log10(in2initial)+(1/insteps));
% First scan with increasing beta2 and decreasing s2
while a <= in2stop && (-a-diff) >= instart
    in2 = 10^(a);
    in = 10^(1*(-a-diff));
    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
    if Flag == 1
        for h = 1:length(A(:,1))
            resrows = resrows + 1;
            stab = stabilityss(F,A(h,:),in,in2);
            result(resrows,:) = [stab,in,in2];
        end
    else 
        break
    end
    if length(A(:,1)) < 2
        a = a - (1/insteps);
        while a <= in2stop && (-a-diff) >= instart
            in2 = 10^(a);
            in = 10^(-a-diff);
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag ==1            
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                a = a - (1/insteps/5);
                while a <= in2stop && (-a-diff) >= instart
                    in2 = 10^(a);
                    in = 10^(-a-diff);
                    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
                    if Flag ==1            
                        for h = 1:length(A(:,1))
                            resrows = resrows + 1;
                            stab = stabilityss(F,A(h,:),in,in2);
                            result(resrows,:) = [stab,in,in2];
                        end
                    else
                        break
                    end
                    if length(A(:,1)) < 2
                        bifurrows = bifurrows +1;
                        bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                        break
                    else
                        E=A;
                    end
                    a = a + (1/insteps/20);
                end
                break
            else
                E = A;
            end
            a = a + (1/insteps/5);
        end
        break
    else
        E = A;
    end
    a = a + (1/insteps);
end
E = D;
a = (log(in2initial)/log(10));
% Then scan with decreasing beta2 and increasing s2
while a >= in2start && (-a-diff) <= instop
    in2 = 10^(a);
    in = 10^(1*(-a-diff));
    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
    if Flag == 1
        for h = 1:length(A(:,1))
            resrows = resrows + 1;
            stab = stabilityss(F,A(h,:),in,in2);
            result(resrows,:) = [stab,in,in2];
        end
    else 
        break
    end
    if length(A(:,1)) < 2
        a = a + (1/insteps);
        while a >= in2start && (-a-diff) <= instop
            in2 = 10^(a);
            in = 10^(-a-diff);
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag == 1
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                a = a + (1/insteps/5);
                while a >= in2start && (-a-diff) <= instop
                    in2 = 10^(a);
                    in = 10^(-a-diff);
                    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
                    if Flag == 1
                        for h = 1:length(A(:,1))
                            resrows = resrows + 1;
                            stab = stabilityss(F,A(h,:),in,in2);
                            result(resrows,:) = [stab,in,in2];
                        end
                    else
                        break
                    end
                    if length(A(:,1)) < 2
                        bifurrows = bifurrows +1;
                        bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                        break
                    else
                        E=A;
                    end
                    a = a - (1/insteps/20);
                end
                break
            else
                E = A;
            end
            a = a - (1/insteps/5);
        end
        break
    else
        E = A;
    end
    a = a - (1/insteps);
end

%--------------------------------------------------------------------------
% Within the bistable region, scan in two directions for stability switch;
% for increasing in2 and constant in, and increasing in and constant in2
% (scanning for decreasing values of in is unnecessary based on experience
% with the system)
%--------------------------------------------------------------------------

nrows = 0;
N = zeros(nrows,3);
for j=1:length(result(:,1))
    k=1;
    xx = 1;
    while k<=length(N(:,1))
        if(result(j,4:5) == N(k,1:2))
            xx=0;
            break
        end
        k = k +1;
    end
    if(xx)
        nrows = nrows + 1;
        N(nrows,1:2) = result(j,4:5);
    end
end
for i=1:length(N(:,1))
    nstab = 0;
    for j=1:length(result(:,1))
        if N(i,1)== result(j,4) && N(i,2)==result(j,5) && result(j,3)>1
            nstab = nstab +1;            
        end
    end
    N(i,3)= nstab;
end

for i = 1:length(N(:,1))
    if N(i,3)>1
        erows = 0;
        E = zeros(erows,2);
        for j = 1:length(result(:,1))
            if N(i,1) == result(j,4) && N(i,2)== result(j,5)
                erows = erows + 1;
                E(erows,:) = result(j,1:2);
            end
        end
        D = E;
        in = N(i,1);
        a = log10(N(i,2));
        while a <= in2stop
            in2 = 10^(a);             
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag == 1
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                a = a - (1/insteps);
                while a <= in2stop
                    in2 = 10^(a);
                    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
                    if Flag == 1
                        for h = 1:length(A(:,1))
                            resrows = resrows + 1;
                            stab = stabilityss(F,A(h,:),in,in2);
                            result(resrows,:) = [stab,in,in2];
                        end
                    else
                        break
                    end
                    if length(A(:,1)) < 2
                        bifurrows = bifurrows +1;
                        bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                        break
                    else
                        E=A;
                    end
                    a = a + (1/insteps/20);
                end
                break
            else
                E = A;
            end
            a = a + (1/insteps); %increasing value of in2 from multistable point
        end
        E = D;
        in2 = N(i,2);
        a = log10(N(i,1));
        while a <= instop
            in = 10^(a);            
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag == 1
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                a = a - (1/insteps);
                while a <= instop
                    in = 10^(a);
                    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
                    if Flag == 1
                        for h = 1:length(A(:,1))
                            resrows = resrows + 1;
                            stab = stabilityss(F,A(h,:),in,in2);
                            result(resrows,:) = [stab,in,in2];
                        end
                    else
                        break
                    end
                    if length(A(:,1)) < 2
                        bifurrows = bifurrows +1;
                        bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                        break
                    else
                        E=A;
                    end
                    a = a + (1/insteps/20);
                end
                break
            else
                E = A;
            end
            a = a + (1/insteps); %increasing value of in
        end
    end
end

%--------------------------------------------------------------------------
% Make a new "starting line". Keeping in2 constant while in is waried. Save
% both in restult and H
%--------------------------------------------------------------------------

hrows = 0;
H = zeros(hrows,5);
in2 = in2initial;
E = stestasea(F,minimum,maximum,nsteps,lim,tol,ininitial,in2initial);
D = E;
a = (log10(ininitial)+(1/insteps));
while a <= instop
    in = 10^(a);            
    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
    if Flag == 1
        for h = 1:length(A(:,1))
            resrows = resrows + 1;
            stab = stabilityss(F,A(h,:),in,in2);
            result(resrows,:) = [stab,in,in2];
            hrows = hrows +1;
            H(hrows,:)=[stab,in,in2];
        end
    else
        break
    end
    if length(A(:,1)) < 2
        a = a - (1/insteps);
        while a <= instop
            in = 10^(a);
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag == 1
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                    hrows = hrows +1;
                    H(hrows,:)=[stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                bifurrows = bifurrows +1;
                bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                break
            else
                E=A;
            end
            a = a + (1/insteps/20);
        end
        break
    else
        E = A;
    end
    a = a + (1/insteps); %increasing value of in
end

E = D;
a = (log10(ininitial)-(1/insteps));
while a >= instart
    in = 10^(a);            
    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
    if Flag == 1
        for h = 1:length(A(:,1))
            resrows = resrows + 1;
            stab = stabilityss(F,A(h,:),in,in2);
            result(resrows,:) = [stab,in,in2];
            hrows = hrows +1;
            H(hrows,:)=[stab,in,in2];
        end
    else
        break
    end
    if length(A(:,1)) < 2
        a = a + (1/insteps);
        while a >= instart
            in = 10^(a);
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag == 1
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                    hrows = hrows +1;
                    H(hrows,:)=[stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                bifurrows = bifurrows +1;
                bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                break
            else
                E=A;
            end
            a = a - (1/insteps/20);
        end
        break
    else
        E = A;
    end
    a = a - (1/insteps); %increasing value of in
end


nrows = 0;
N = zeros(nrows,3);
for j=1:length(H(:,1))
    k=1;
    xx = 1;
    while k<=length(N(:,1))
        if(H(j,4:5) == N(k,1:2))
            xx=0;
            break
        end
        k = k +1;
    end
    if(xx)
        nrows = nrows + 1;
        N(nrows,1:2) = H(j,4:5);
    end
end
for i=1:length(N(:,1))
    nstab = 0;
    for j=1:length(H(:,1))
        if N(i,1)== H(j,4) && N(i,2)==H(j,5) && H(j,3)>1
            nstab = nstab +1;            
        end
    end
    N(i,3)= nstab;
end

for i = 1:length(N(:,1))
    if N(i,3)>1
        erows = 0;
        E = zeros(erows,2);
        for j = 1:length(result(:,1))
            if N(i,1) == result(j,4) && N(i,2)== result(j,5)
                erows = erows + 1;
                E(erows,:) = result(j,1:2);
            end
        end
        D = E;
        in = N(i,1);
        a = log10(N(i,2));
        while a >= in2start
            in2 = 10^(a);             
            [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
            if Flag == 1
                for h = 1:length(A(:,1))
                    resrows = resrows + 1;
                    stab = stabilityss(F,A(h,:),in,in2);
                    result(resrows,:) = [stab,in,in2];
                end
            else
                break
            end
            if length(A(:,1)) < 2
                a = a + (1/insteps);
                while a >= in2start
                    in2 = 10^(a);
                    [A,Flag] = rwrthom2nextss(F,E,in,in2,w,s,wmod,smod,tol,lim,ilim);
                    if Flag == 1
                        for h = 1:length(A(:,1))
                            resrows = resrows + 1;
                            stab = stabilityss(F,A(h,:),in,in2);
                            result(resrows,:) = [stab,in,in2];
                        end
                    else
                        break
                    end
                    if length(A(:,1)) < 2
                        bifurrows = bifurrows +1;
                        bifur(bifurrows,:) = ((result(resrows,4:5)+result(resrows-1,4:5))/2);
                        break
                    else
                        E=A;
                    end
                    a = a - (1/insteps/20);
                end
                break
            else
                E = A;
            end
            a = a - (1/insteps); %decreasing value of in2 from multistable point
        end
    end
end



%--------------------------------------------------------------------------
% Prepare to plot the results
%--------------------------------------------------------------------------

birows = 0;
BI = zeros(birows,3);
for j=1:length(result(:,1))
    k=1;
    xx = 1;
    while k<=length(BI(:,1))
        if(result(j,4:5) == BI(k,1:2))
            xx=0;
            break
        end
        k = k +1;
    end
    if(xx)
        birows = birows + 1;
        BI(birows,1:2) = result(j,4:5);
    end 
%     waitbar(j/length(result(:,1)));
end
% close(h)

for i=1:length(BI(:,1))
    nstab = 0;
    for j=1:length(result(:,1))
        if BI(i,1)== result(j,4) && BI(i,2)==result(j,5) && result(j,3)>1
            nstab = nstab +1;            
        end
    end
    BI(i,3)= nstab;
end


% upperrows = 0;
% lowerrows = 0;
% bifurupper = zeros(upperrows,2);
% bifurlower = zeros(lowerrows,2);
% 
% for i= 1:length(bifur(:,1))
%     if bifur(i,1) > bifur(i,2)
%         lowerrows = lowerrows + 1;
%         bifurlower(lowerrows,:) = bifur(i,:);
%     elseif bifur(i,2) > bifur(i,1)
%         upperrows = upperrows +1;
%         bifurupper(upperrows,:) = bifur(i,:);
%     else
%         upperrows = upperrows +1;
%         bifurupper(upperrows,:) = bifur(i,:);
%         lowerrows = lowerrows + 1;
%         bifurlower(lowerrows,:) = bifur(i,:);
%     end
% end
% sortedupper = sort(bifurupper);
% sortedlower = sort(bifurlower);
% 
%--------------------------------------------------------------------------
%Plot the data
%--------------------------------------------------------------------------
% 
% %Phase plot
% for i=1:length(BI(:,1))
%     hold on
%     if BI(i,3)==1
%         scatter(BI(i,1),BI(i,2),'.g')
%     elseif BI(i,3)==2
%         scatter(BI(i,1),BI(i,2),'.r')
%     else
%         scatter(BI(i,1),BI(i,2),'.b')
%     end
% end
% set(gca,'xscale','log','yscale','log')
% xlabel('s_2','FontSize',16)
% ylabel('\beta_2','FontSize',16)
% title('\it{s_2 vs \beta_2, \beta_1 = 17.5, s_1 = 0.01, K_1 = K_2 = 10, 11.04.2011}','FontSize',16)
% hold off
% % 
% % 
% % Bifurcation limit plot - scatter
% for i=1:length(bifur(:,1))
%     hold on
%     scatter(bifur(i,1),bifur(i,2),'.k')
% %     scatter(bifur(i,2),bifur(i,1),'.k') % other param symm
% end
% set(gca,'xscale','log','yscale','log')
% xlabel('s_2','FontSize',16)
% ylabel('\beta_2','FontSize',16)
% title('\it{s_2 vs \beta_2, \beta_1 = 17.5, s_1 = 0.01, K_1 = K_2 = 10, 11.04.2011}','FontSize',16)
% hold off
% 
% % Bifurcation limit plot
% 
% hold on
% plot(sortedupper(:,1),sortedupper(:,2),'k')
% plot(sortedlower(:,1),sortedlower(:,2),'k')
% set(gca,'xscale','log','yscale','log')
% xlabel('s_2','FontSize',16)
% ylabel('\beta_2','FontSize',16)
% title('\it{s_2 vs \beta_2, \beta_1 = 17.5, s_1 = 0.01, K_1 = K_2 = 10, 26.02.2011}','FontSize',16)
% hold off
% 
%---------------------------------------------------------
%Print the results to textfile
%---------------------------------------------------------


[resrows rescols] = size(result);
filename = '2011-04-16_result_p1_p2_stab_s2_beta2.txt';
fid = fopen(filename,'w');
for row=1:resrows
    fprintf(fid, '%f %f %f %f %f \n', result(row,:));
end
fclose(fid);

[BIrows BIcols] = size(BI);
filename = '2011-04-16_BI_s2_beta2_nstab.txt';
fid = fopen(filename,'w');
for row=1:BIrows
    fprintf(fid, '%f %f %f \n', BI(row,:));
end
fclose(fid);

[bifurrows bifurcols] = size(bifur);
filename = '2011-04-16_bifur_s2_beta2.txt';
fid = fopen(filename,'w');
for row=1:bifurrows
    fprintf(fid, '%f %f \n', bifur(row,:));
end
fclose(fid);

toc