% Plotting of Dizzy-simulations based on Gardner et al. (2000)
% By Sigurd Hagen Johansen
% 04.05.2011

% The data sets were made by running the dizzy model
% cItetRmodelassymGardnercIoff.cmdl and cItetRmodelassymGardnercIon.cmdl

% Import the data as 'p1high' and 'p1low'

cIoff = importdata('cItetRmodelassymGardnercIoff_gibson-bruck_start-0_stop-1000000_respoints-100000_ensize-1');
cIon = importdata('cItetRmodelassymGardnercIon_ci0-65_tetr0-1_gibson-bruck_start-0_stop-1000000_respoints-100000_ensize-1');
cIoff=cIoff.data ;
% The colheaders contain:
%'% time'    ' TetR'    ' cI'

%--------------------------------------------------------------------------
% Create plots of the two variables against time
%--------------------------------------------------------------------------

f1 = figure;
hold on
p1=plot(cIoff(:,1),cIoff(:,2),'r');%TetR aganist time
p2=plot(cIoff(:,1),cIoff(:,3),'b');%cI against time
legend('TetR','cI')
hold off
close(f1)

f2 = figure;
hold on
p3=plot(cIon(:,1),cIon(:,2),'r');%TetR aganist time
p4=plot(cIon(:,1),cIon(:,3),'b');%cI against time
legend('TetR','cI')
hold off
close(f2)


%--------------------------------------------------------------------------
% Create effective potential landscape drawings
%--------------------------------------------------------------------------


f3 = figure;
hold on
pot = [cIoff(:,3)-cIoff(:,2);cIon(:,3)-cIon(:,2)];
x=min(pot(:,1)):max(pot(:,1));
n = hist(pot(:,1),x);
sumdiff= sum(pot(:,1));
normdiff = n/sumdiff;
potential = -log(normdiff);
p5 = plot(x,potential,'LineWidth',1.5);
xlabel('cI - TetR','FontSize',12)
ylabel('-ln(P(cI - TetR))','FontSize',12)
axis([-100,100,4,15]);
print('-dpng','stochgardner.png');
hold off
close(f3);


