% Plotting of Dizzy-simulations
% By Sigurd Hagen Johansen
% 18.04.2011

% The graphs were made data generated by running the model files
% cItetRmodelbeta1vardecreasing.cmdl and cItetRmodelbeta1varincreasing.cmdl
% in the Dizzy-package with the gibson-bruck algorithm

decreasing = importdata('cItetRmodelbeta1vardecreasing_ci0-150_tetr0-1_gibson-bruck_start-0_stop-200000_respoints-200000_ensize-1');
increasing = importdata('cItetRmodelbeta1varincreasing_ci0-1_tetr0-35_gibson-bruck_start-0_stop-200000_respoints-200000_ensize-1');

stepsize = 10000;

% The colheaders contain:
% '% time'    ' TetR'    ' beta1'    ' cI'    ' lambda1'


f5 = figure;
hold on
col = hsv(21);
for i=1:19
p = [decreasing(i*stepsize+1:(i+1)*stepsize,4)-decreasing(i*stepsize+1:(i+1)*stepsize,2);increasing(length(increasing(:,1))-i*stepsize+1:length(increasing(:,1))-(i-1)*stepsize,4)-increasing(length(increasing(:,1))-i*stepsize+1:length(increasing(:,1))-(i-1)*stepsize,2)];
x=min(p(:,1)):max(p(:,1));
n = hist(p(:,1),x);
sumdiff= sum(p(:,1));
normdiff = n/sumdiff;
potential = -log(normdiff);
betaval = ones(1,length(potential(1,:)))*decreasing(i*stepsize+1,3);
plot3(betaval,x,potential,'color',col(i,:),'Linewidth',1.5)
end
xlabel('\beta_1','FontSize',12)
ylabel('p_1 - p_2','FontSize',12)
zlabel('-ln(P(p_1 - p_2))','FontSize',12)
set(gca, 'xscale', 'log')
view([21 48])
grid on
% axis([-150,150,2,16])
legend( ['\beta_1 =',sprintf('%3.1f',decreasing(1*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(2*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(3*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(4*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(5*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(6*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(7*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(8*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(9*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(10*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(11*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(12*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(13*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(14*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(15*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(16*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(17*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(18*stepsize+1,3))]  ...
       ,['\beta_1 =',sprintf('%3.1f',decreasing(19*stepsize+1,3))]  ...
       ,'location', 'EastOutside') 
print -dpng stochbeta1potential.png     % save the current figure as a png
hold off
close(f5)

%Convert 'cI'(P^1) values to 'cI_2'(P^1_2) by: 'cI_2' = 'cI'^2/10
%Convert 'TetR' (P^2) values to 'TetR_2' by: 'TetR_2' = 'TetR'^2/10
K1 = 10;
decreasing(:,2)= decreasing(:,2).^2./K1;
decreasing(:,4)= decreasing(:,4).^2./K1;
increasing(:,2)= increasing(:,2).^2./K1;
increasing(:,4)= increasing(:,4).^2./K1;

% The colheaders contain:
% '% time'    ' TetR_2'    ' beta1'    ' cI_2'    ' lambda1'

%--------------------------------------------------------------------------
% plot the 'cI' column against 'beta1' for both the simulations
%--------------------------------------------------------------------------
f1 = figure;
hold on
p1 = plot(decreasing(:,3),decreasing(:,4),'-r');
set(gca,'xscale','log')
xlabel('\beta_1','FontSize',16)
ylabel('P^1_2','FontSize',16)
print('-dpng','stochbeta1vardecreasing.png');
hold off
close(f1)

f2 = figure;
hold on
p2 = plot(increasing(:,3),increasing(:,4),'-r');
set(gca,'xscale','log')
xlabel('\beta_1','FontSize',16)
ylabel('P^1_2','FontSize',16)
print('-dpng','stochbeta1varincreasing.png');
hold off
close(f2)

%--------------------------------------------------------------------------
% plot the 'cI' column against 'beta1' for both the simulations in one plot
%--------------------------------------------------------------------------

f3 = figure;
hold on
p3 = plot(decreasing(:,3),decreasing(:,4),'-r');
p4 = plot(increasing(:,3),increasing(:,4),'-b');
set(gca,'xscale','log','yscale','log')
xlabel('\beta_1','FontSize',12)
ylabel('P^1_2','FontSize',12)
print('-dpng','stochbeta1var.png');
hold off
close(f3)

%--------------------------------------------------------------------------
% Calculate the average, standard deviations, CoV and Fano factor for the
% 'cI' at each beta-value for both simulations separately 
%--------------------------------------------------------------------------

% There are 10000 result points for each 'beta1'-value
stepsize = 10000;

% create ouput matrix for the values
decstatrows = 0;
decstat = zeros(decstatrows,5); %statistical values from decreasing
incstatrows = 0;
incstat = zeros(incstatrows,5); %statistical values from increasing

for i = 1:stepsize:length(decreasing(:,1))
    decstatrows = decstatrows + 1;
    decstat(decstatrows,1) = decreasing(i,3); % beta value in (x,1)
    decstat(decstatrows,2) = mean(decreasing(i:(i+stepsize-1),4)); % cI average value in (x,2)
    decstat(decstatrows,3) = std(decreasing(i:(i+stepsize-1),4)); % cI standard deviation in (x,3)
    decstat(decstatrows,4) = cov(decreasing(i:(i+stepsize-1),4)); % cI CoV in (x,4)
    decstat(decstatrows,5) = (decstat(decstatrows,3))^2/decstat(decstatrows,2); % cI Fano factor in (x,5)
end

for i = 1:stepsize:length(increasing(:,1))
    incstatrows = incstatrows + 1;
    incstat(incstatrows,1) = increasing(i,3); % beta value in (x,1)
    incstat(incstatrows,2) = mean(increasing(i:(i+stepsize-1),4)); % cI average value in (x,2)
    incstat(incstatrows,3) = std(increasing(i:(i+stepsize-1),4)); % cI standard deviation in (x,3)
    incstat(incstatrows,4) = cov(increasing(i:(i+stepsize-1),4)); % cI CoV in (x,4)
    incstat(incstatrows,5) = (incstat(incstatrows,3))^2/incstat(incstatrows,2); % cI Fano factor in (x,5)
end

%--------------------------------------------------------------------------
% Plot the average values of the two simulations with standard deviations
% as error bars
%--------------------------------------------------------------------------

f4 = figure;
hold on
errorbar(decstat(:,1),decstat(:,2),decstat(:,3),'-.r','LineWidth',1.5);
errorbar(incstat(:,1),incstat(:,2),incstat(:,3),'-.b','LineWidth',1.5);
set(gca     ,'xscale'   ,'log')
%             ,'yscale'   ,'log')
xlabel('\beta_1','FontSize',12)
ylabel('P_2^1','FontSize',12)
axis([1,100,-1,2200])
legend('Decreasing \beta_1','Increasing \beta_1','location','NorthWest')
print('-dpng','stochbeta1varerrorbar.png');
hold off
close(f4)
