% Plotting of Dizzy-simulations
% By Sigurd Hagen Johansen
% 04.05.2011

% The graphs were made by running the dizzy model
% cItetRmodelvars1cIhigh.cmdl and cItetRmodelvars1cIlow

% Import the data as 'p1high' and 'p1low'

p1high = importdata('cItetRmodelvars1cIhigh_ci0-35_tetr0-1_gibson-bruck_start-0_stop-300000_respoints-300000_ensize-1');
p1low = importdata('cItetRmodelvars1cIlow_ci0-1_tetr0-35_gibson-bruck_start-0_stop_300000_respoints-300000_ensize-1');
p1high=p1high.data ;
% The colheaders contain:

%'% time'    ' TetR'    ' cI'    ' lambda1'    ' mu1'    ' nu1'    ' s1'

% There are 10000 result points for each 's1'-value
stepsize = 10000;

%--------------------------------------------------------------------------
% Create potential drawings to describe the variation
%--------------------------------------------------------------------------

% The colheaders contain:
%'% time'    ' TetR'    ' cI'    ' lambda1'    ' mu1'    ' nu1'    ' s1'

f5 = figure;
leg = 0;
hold on
col = hsv(30);
for i=2:2:28    
    p = [p1high(i*stepsize+1:(i+1)*stepsize,3)-p1high(i*stepsize+1:(i+1)*stepsize,2);p1low(i*stepsize+1:(i+1)*stepsize,3)-p1low(i*stepsize+1:(i+1)*stepsize,2)];
    x=min(p(:,1)):max(p(:,1));
    n = hist(p(:,1),x);
    sumdiff= sum(p(:,1));
    normdiff = n/sumdiff;
    potential = -log(normdiff);
    svalue = ones(1,length(potential(1,:)))*p1high(i*stepsize+1,7);
    plot3(svalue,x,potential,'color',col(i,:),'LineWidth',1.5)
end
set(gca,    'xscale',   'log')
xlabel('s_1','FontSize',12)
ylabel('p_1 - p_2','FontSize',12)
zlabel('-ln(P(p_1 - p_2))','FontSize',12)
view([30,30])
grid on
% axis([-150,150,0,15])
legend(['s_1 = ',sprintf('%1.3f',p1high(2*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(4*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(6*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(8*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(10*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(12*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(14*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(16*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(18*stepsize+1,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(20*stepsize,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(22*stepsize,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(24*stepsize,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(26*stepsize,7))]...
        ,['s_1 = ',sprintf('%1.3f',p1high(28*stepsize,7))]...
        ,'location', 'EastOutside')        
print -dpng stochs1potential.png     % save the current figure as a png
hold off
close(f5)


%Convert 'cI'(P^1) values to 'cI_2'(P^1_2) by: 'cI_2' = 'cI'^2/K1
%Convert 'TetR' (P^2) values to 'TetR_2' by: 'TetR_2' = 'TetR'^2/K1
K1 = 10;
p1high(:,2)= p1high(:,2).^2./K1;
p1high(:,3)= p1high(:,3).^2./K1;
p1low(:,2)= p1low(:,2).^2./K1;
p1low(:,3)= p1low(:,3).^2./K1;



%--------------------------------------------------------------------------
% plot the 'cI' column against 's1' for both the simulations
%--------------------------------------------------------------------------
 
f1 = figure;
hold on
plot1 = plot(p1high(:,7),p1high(:,3),'-r');
set(gca,'xscale','log')
xlabel('s_1','FontSize',16)
ylabel('p_1','FontSize',16)
print('-dpng','stochs1varp1high.png');
hold off
close(f1)

f2 = figure;
hold on
plot2 = plot(p1low(:,7),p1low(:,3),'-r');
set(gca,'xscale','log')
xlabel('s_1','FontSize',16)
ylabel('p_1','FontSize',16)
print('-dpng','stochs1varp1low.png');
hold off
close(f2)


%--------------------------------------------------------------------------
% plot the 'cI' column against 's1' for both the simulations in one plot
%--------------------------------------------------------------------------

f3 = figure;
hold on
plot3 = plot(p1high(:,7),p1high(:,3),'-r');
plot4 = plot(p1low(:,7),p1low(:,3),'-b');
set(gca,'xscale','log')
xlabel('s_1','FontSize',12)
ylabel('p_1','FontSize',12)
print('-dpng','stochs1var.png');
hold off
close(f3)

%--------------------------------------------------------------------------
% Calculate the average, standard deviations, CoV and Fano factor for the
% 'cI' at each s1-value for both simulations separately 
%--------------------------------------------------------------------------

% create ouput matrix for the values
highstatrows = 0;
highstat = zeros(highstatrows,5); %statistical values from p1high
lowstatrows = 0;
lowstat = zeros(lowstatrows,5); %statistical values from p1low

for i = 1:stepsize:length(p1high(:,1))
    highstatrows = highstatrows + 1;
    highstat(highstatrows,1) = p1high(i,7); % s1 value in (x,1)
    highstat(highstatrows,2) = mean(p1high(i:(i+stepsize-1),3)); % cI average value in (x,2)
    highstat(highstatrows,3) = std(p1high(i:(i+stepsize-1),3)); % cI standard deviation in (x,3)
    highstat(highstatrows,4) = cov(p1high(i:(i+stepsize-1),3)); % cI CoV in (x,4)
    highstat(highstatrows,5) = (highstat(highstatrows,3))^2/highstat(highstatrows,2); % cI Fano factor in (x,5)
end

for i = 1:stepsize:length(p1low(:,1))
    lowstatrows = lowstatrows + 1;
    lowstat(lowstatrows,1) = p1low(i,7); % s1 value in (x,1)
    lowstat(lowstatrows,2) = mean(p1low(i:(i+stepsize-1),3)); % cI average value in (x,2)
    lowstat(lowstatrows,3) = std(p1low(i:(i+stepsize-1),3)); % cI standard deviation in (x,3)
    lowstat(lowstatrows,4) = cov(p1low(i:(i+stepsize-1),3)); % cI CoV in (x,4)
    lowstat(lowstatrows,5) = (lowstat(lowstatrows,3))^2/lowstat(lowstatrows,2); % cI Fano factor in (x,5)
end

%--------------------------------------------------------------------------
% Plot the average values of the two simulations with standard deviations
% as error bars
%--------------------------------------------------------------------------

f4 = figure;
hold on
errorbar(highstat(:,1),highstat(:,2),highstat(:,3),'.-r','LineWidth',1.5);
errorbar(lowstat(:,1),lowstat(:,2),lowstat(:,3),'.-b','LineWidth',1.5);
set(gca     ,'xscale'   ,'log')
%             ,'yscale'   ,'log')
xlabel('s_1','FontSize',12)
ylabel('P^1_2','FontSize',12)
legend('cI_0 on','cI_0 off','location','NorthWest')
% axis([1,100,0,160])
print('-dpng','stochs1varerrorbar.png');
hold off
close(f4)







